#ifndef EFL_UI_PAGER_IMPL_HH
#define EFL_UI_PAGER_IMPL_HH

#include "efl_ui_pager.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type Pager::transition_set( ::efl::eolian::in_traits< ::efl::page::Transition>::type transition) const
{
    ::efl_ui_pager_transition_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Page_Transition*,  ::efl::eolian::in_traits< ::efl::page::Transition>::type>(transition));
}
inline ::efl::eolian::return_traits<void>::type Pager::indicator_set( ::efl::eolian::in_traits< ::efl::page::Indicator>::type indicator) const
{
    ::efl_ui_pager_indicator_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Page_Indicator*,  ::efl::eolian::in_traits< ::efl::page::Indicator>::type>(indicator));
}
inline ::efl::eolian::return_traits<int>::type Pager::current_page_get() const
{
   int __return_value =  ::efl_ui_pager_current_page_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::current_page_set( ::efl::eolian::in_traits<int>::type index) const
{
    ::efl_ui_pager_current_page_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
}
inline ::efl::eolian::return_traits<void>::type Pager::scroll_block_get( ::efl::eolian::out_traits<bool>::type prev,  ::efl::eolian::out_traits<bool>::type next) const
{
   Eina_Bool __out_param_prev = {};
   Eina_Bool __out_param_next = {};
    ::efl_ui_pager_scroll_block_get(_eo_ptr()
      , & __out_param_prev
      , & __out_param_next);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(prev, __out_param_prev);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(next, __out_param_next);
}
inline ::efl::eolian::return_traits<void>::type Pager::scroll_block_set( ::efl::eolian::in_traits<bool>::type prev,  ::efl::eolian::in_traits<bool>::type next) const
{
    ::efl_ui_pager_scroll_block_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(prev)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(next));
}
inline ::efl::eolian::return_traits<Efl_Ui_Pager_Loop>::type Pager::loop_mode_get() const
{
   Efl_Ui_Pager_Loop __return_value =  ::efl_ui_pager_loop_mode_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Pager_Loop>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::loop_mode_set( ::efl::eolian::in_traits<Efl_Ui_Pager_Loop>::type loop) const
{
    ::efl_ui_pager_loop_mode_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Pager_Loop,  ::efl::eolian::in_traits<Efl_Ui_Pager_Loop>::type>(loop));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Pager::page_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_pager_page_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::page_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type size) const
{
    ::efl_ui_pager_page_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(size));
}
inline ::efl::eolian::return_traits<int>::type Pager::padding_get() const
{
   int __return_value =  ::efl_ui_pager_padding_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::padding_set( ::efl::eolian::in_traits<int>::type padding) const
{
    ::efl_ui_pager_padding_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(padding));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type Pager::transition_set( ::efl::eolian::in_traits< ::efl::page::Transition>::type transition) const
{
    ::efl_ui_pager_transition_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Page_Transition*,  ::efl::eolian::in_traits< ::efl::page::Transition>::type>(transition));
}
inline ::efl::eolian::return_traits<void>::type Pager::indicator_set( ::efl::eolian::in_traits< ::efl::page::Indicator>::type indicator) const
{
    ::efl_ui_pager_indicator_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Page_Indicator*,  ::efl::eolian::in_traits< ::efl::page::Indicator>::type>(indicator));
}
inline ::efl::eolian::return_traits<int>::type Pager::current_page_get() const
{
   int __return_value =  ::efl_ui_pager_current_page_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::current_page_set( ::efl::eolian::in_traits<int>::type index) const
{
    ::efl_ui_pager_current_page_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(index));
}
inline ::efl::eolian::return_traits<void>::type Pager::scroll_block_get( ::efl::eolian::out_traits<bool>::type prev,  ::efl::eolian::out_traits<bool>::type next) const
{
   Eina_Bool __out_param_prev = {};
   Eina_Bool __out_param_next = {};
    ::efl_ui_pager_scroll_block_get(_eo_ptr()
      , & __out_param_prev
      , & __out_param_next);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(prev, __out_param_prev);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(next, __out_param_next);
}
inline ::efl::eolian::return_traits<void>::type Pager::scroll_block_set( ::efl::eolian::in_traits<bool>::type prev,  ::efl::eolian::in_traits<bool>::type next) const
{
    ::efl_ui_pager_scroll_block_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(prev)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(next));
}
inline ::efl::eolian::return_traits<Efl_Ui_Pager_Loop>::type Pager::loop_mode_get() const
{
   Efl_Ui_Pager_Loop __return_value =  ::efl_ui_pager_loop_mode_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Pager_Loop>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::loop_mode_set( ::efl::eolian::in_traits<Efl_Ui_Pager_Loop>::type loop) const
{
    ::efl_ui_pager_loop_mode_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Pager_Loop,  ::efl::eolian::in_traits<Efl_Ui_Pager_Loop>::type>(loop));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Pager::page_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_pager_page_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::page_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type size) const
{
    ::efl_ui_pager_page_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(size));
}
inline ::efl::eolian::return_traits<int>::type Pager::padding_get() const
{
   int __return_value =  ::efl_ui_pager_padding_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Pager::padding_set( ::efl::eolian::in_traits<int>::type padding) const
{
    ::efl_ui_pager_padding_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(padding));
}
inline efl::ui::Pager::operator ::efl::ui::Pager() const { return *static_cast< ::efl::ui::Pager const*>(static_cast<void const*>(this)); }
inline efl::ui::Pager::operator ::efl::ui::Pager&() { return *static_cast< ::efl::ui::Pager*>(static_cast<void*>(this)); }
inline efl::ui::Pager::operator ::efl::ui::Pager const&() const { return *static_cast< ::efl::ui::Pager const*>(static_cast<void const*>(this)); }
} } }
#endif
